'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

// The theme file is based on the specification at https://system-ui.com/theme
// e.g. for sport:
// const [sport300, sport400, sport500, sport600, sport800] = colors.blue

var colors = {
  reds: ["#660505", //news-100
  "#8B0000", //news-200
  "#AB0613", //news-300
  "#C70000", //news-400
  "#FF5943", //news-500
  "#FFBAC8", //news-600
  "#FFF4F2" //news-800
  ],
  oranges: ["#672005", //opinion-100
  "#8D2700", //opinion-200
  "#BD5318", //opinion-300
  "#E05E00", //opinion-400
  "#FF7F0F", //opinion-500
  "#F9B376", //opinion-600
  "#FEF9F5" //opinion-800
  ],
  blues: ["#003C60", //sport-100
  "#004E7C", //sport-200
  "#005689", //sport-300
  "#0084C6", //sport-400
  "#00B2FF", //sport-500
  "#90DCFF", //sport-600
  "#F1F8FC", //sport-800
  "#001536", //brand-100
  "#041F4A", //brand-300
  "#052962", //brand-400
  "#007ABC", //brand-500
  "#506991", //brand-600
  "#C1D8FC" //brand-800
  ],
  browns: ["#3E3323", //culture-100
  "#574835", //culture-200
  "#6B5840", //culture-300
  "#A1845C", //culture-400
  "#EACCA0", //culture-500
  "#E7D4B9", //culture-600
  "#FBF6EF" //culture-800
  ],
  pinks: ["#510043", //lifestyle-100
  "#650054", //lifestyle-200
  "#7D0068", //lifestyle-300
  "#BB3B80", //lifestyle-400
  "#FFABDB", //lifestyle-500
  "#FEC8D3", //lifestyle-600
  "#FEEEF7" //lifestyle-800
  ],
  yellows: ["#F3C100", //brandAlt-200
  "#FFD900", //brandAlt-300
  "#FFE500" //brandAlt-400
  ],
  greens: ["#185E36", //green-200
  "#22874D", //green-400
  "#4B8878", //labs-200
  "#65A897", //labs-300
  "#69D1CA" //labs-400
  ],
  grays: ["#000000", //neutral-0
  "#121212", //neutral-7
  "#1A1A1A", //neutral-10
  "#333333", //neutral-20
  "#767676", //neutral-46
  "#999999", //neutral-60
  "#DCDCDC", //neutral-86
  "#EDEDED", //neutral-93
  "#F6F6F6", //neutral-97
  "#FFFFFF", //neutral-100
  "#222527", //specialReport-100
  "#303538", //specialReport-200
  "#3F464A", //specialReport-300
  "#63717A", //specialReport-400
  "#ABC2C9", //specialReport-500
  "#33393D" //dynamo-400
  ]
};

// Global colour names that correspond to https://www.theguardian.design/2a1e5182b/p/938810-colour/b/587ef3
var brand = {
  100: colors.blues[7],
  300: colors.blues[8],
  400: colors.blues[9],
  500: colors.blues[10],
  600: colors.blues[11],
  800: colors.blues[12],
  // legacy names: please do not use
  dark: colors.blues[8],
  main: colors.blues[9],
  bright: colors.blues[10],
  pastel: colors.blues[11],
  faded: colors.blues[12]
};
var brandAlt = {
  200: colors.yellows[0],
  300: colors.yellows[1],
  400: colors.yellows[2],
  // legacy names: please do not use
  dark: colors.yellows[1],
  main: colors.yellows[2]
}; // continue to expose legacy name for compatibility
var neutral = {
  0: colors.grays[0],
  7: colors.grays[1],
  10: colors.grays[2],
  20: colors.grays[3],
  46: colors.grays[4],
  60: colors.grays[5],
  86: colors.grays[6],
  93: colors.grays[7],
  97: colors.grays[8],
  100: colors.grays[9]
};
var error = {
  400: colors.reds[3],
  500: colors.reds[4],
  // legacy names: please do not use
  main: colors.reds[3],
  bright: colors.reds[4]
};
var success = {
  400: colors.greens[1],
  // legacy names: please do not use
  main: colors.greens[1]
};
var sport = {
  100: colors.blues[0],
  200: colors.blues[1],
  300: colors.blues[2],
  400: colors.blues[3],
  500: colors.blues[4],
  600: colors.blues[5],
  800: colors.blues[6],
  // legacy names: please do not use
  dark: colors.blues[2],
  main: colors.blues[3],
  bright: colors.blues[4],
  pastel: colors.blues[5],
  faded: colors.blues[6]
};

var background = {
  primary: neutral[100],
  inverse: neutral[10],
  ctaPrimary: brand[400],
  ctaPrimaryHover: "#234B8A",
  ctaSecondary: brand[800],
  ctaSecondaryHover: "#ACC9F7",
  input: neutral[100],
  inputChecked: brand[500]
};

var brandBackground = {
  primary: brand[400],
  inputChecked: neutral[100],
  ctaPrimary: neutral[100],
  ctaPrimaryHover: "#E0E0E0",
  ctaSecondary: brand[600],
  ctaSecondaryHover: "#234B8A"
};

var brandAltBackground = {
  primary: brandAlt[400],
  ctaPrimary: neutral[7],
  ctaPrimaryHover: "#454545",
  ctaSecondary: brandAlt[200],
  ctaSecondaryHover: "#F2AE00"
};

var border = {
  primary: neutral[60],
  secondary: neutral[86],
  success: success[400],
  error: error[400],
  input: neutral[60],
  inputChecked: brand[500],
  inputHover: brand[500],
  focusHalo: sport[500]
};

var brandBorder = {
  primary: brand[800],
  success: success[400],
  error: error[500],
  input: brand[800],
  inputChecked: neutral[100],
  inputHover: neutral[100]
};

var text = {
  primary: neutral[7],
  supporting: neutral[46],
  success: success[400],
  error: error[400],
  ctaPrimary: neutral[100],
  ctaSecondary: brand[400],
  anchorPrimary: brand[500],
  anchorSecondary: neutral[7],
  userInput: neutral[7],
  inputLabel: neutral[7],
  inputLabelSupporting: neutral[46],
  inputChecked: brand[400],
  //choice card only
  inputHover: brand[400],
  //choice card only
  groupLabel: neutral[7],
  groupLabelSupporting: neutral[46]
};

var brandText = {
  primary: neutral[100],
  supporting: brand[800],
  success: success[400],
  error: error[500],
  ctaPrimary: brand[400],
  ctaSecondary: neutral[100],
  anchorPrimary: neutral[100],
  userInput: neutral[100],
  inputLabel: neutral[100],
  inputLabelSupporting: brand[800]
};

var brandAltText = {
  primary: neutral[7],
  supporting: neutral[60],
  ctaPrimary: neutral[100],
  ctaSecondary: neutral[7],
  anchorPrimary: neutral[7]
};

var buttonDefault = {
  button: {
    textPrimary: text.ctaPrimary,
    backgroundPrimary: background.ctaPrimary,
    backgroundPrimaryHover: background.ctaPrimaryHover,
    textSecondary: text.ctaSecondary,
    backgroundSecondary: background.ctaSecondary,
    backgroundSecondaryHover: background.ctaSecondaryHover,
    textTertiary: text.ctaSecondary,
    backgroundTertiary: background.primary
  }
};
var buttonBrand = {
  button: {
    textPrimary: brandText.ctaPrimary,
    backgroundPrimary: brandBackground.ctaPrimary,
    backgroundPrimaryHover: brandBackground.ctaPrimaryHover,
    textSecondary: brandText.ctaSecondary,
    backgroundSecondary: brandBackground.ctaSecondary,
    backgroundSecondaryHover: brandBackground.ctaSecondaryHover,
    textTertiary: brandText.ctaSecondary,
    backgroundTertiary: brandBackground.primary
  }
};
var buttonBrandAlt = {
  button: {
    textPrimary: brandAltText.ctaPrimary,
    backgroundPrimary: brandAltBackground.ctaPrimary,
    backgroundPrimaryHover: brandAltBackground.ctaPrimaryHover,
    textSecondary: brandAltText.ctaSecondary,
    backgroundSecondary: brandAltBackground.ctaSecondary,
    backgroundSecondaryHover: brandAltBackground.ctaSecondaryHover,
    textTertiary: brandAltText.ctaSecondary,
    backgroundTertiary: brandAltBackground.primary
  }
}; // continue to expose legacy theme names

var buttonLight = buttonDefault;
var buttonBrandYellow = buttonBrandAlt;

var inlineErrorDefault = {
  inlineError: {
    text: text.error
  }
};
var inlineErrorBrand = {
  inlineError: {
    text: brandText.error
  }
}; // continue to expose legacy theme names

var inlineErrorLight = inlineErrorDefault;

var checkboxDefault = _objectSpread2({
  checkbox: {
    border: border.input,
    borderHover: border.inputHover,
    borderChecked: border.inputChecked,
    borderError: border.error,
    backgroundChecked: background.inputChecked,
    textLabel: text.inputLabel,
    textLabelSupporting: text.inputLabelSupporting,
    textIndeterminate: text.supporting
  }
}, inlineErrorDefault);
var checkboxBrand = _objectSpread2({
  checkbox: {
    border: brandBorder.input,
    borderHover: brandBorder.inputHover,
    borderChecked: brandBorder.inputChecked,
    borderError: brandBorder.error,
    backgroundChecked: brandBackground.inputChecked,
    textLabel: brandText.inputLabel,
    textLabelSupporting: brandText.inputLabelSupporting,
    textIndeterminate: brandText.supporting
  }
}, inlineErrorBrand); // continue to expose legacy theme names

var checkboxLight = checkboxDefault;

var choiceCardDefault = _objectSpread2({
  choiceCard: {
    textLabel: text.supporting,
    textLabelSupporting: text.supporting,
    textGroupLabel: text.groupLabel,
    textGroupLabelSupporting: text.groupLabelSupporting,
    border: border.input,
    textChecked: text.inputChecked,
    backgroundChecked: "#E3F6FF",
    backgroundTick: background.inputChecked,
    borderChecked: border.inputChecked,
    textHover: text.inputHover,
    borderHover: border.inputHover,
    textError: text.error,
    borderError: border.error
  }
}, inlineErrorDefault);

var linkDefault = {
  link: {
    textPrimary: text.anchorPrimary,
    textPrimaryHover: text.anchorPrimary,
    textSecondary: text.anchorSecondary,
    textSecondaryHover: text.anchorSecondary
  }
};
var linkBrand = {
  link: {
    textPrimary: brandText.anchorPrimary,
    textPrimaryHover: brandText.anchorPrimary
  }
};
var linkBrandAlt = {
  link: {
    textPrimary: brandAltText.anchorPrimary,
    textPrimaryHover: brandAltText.anchorPrimary
  }
}; // continue to expose legacy theme names

var linkLight = linkDefault;
var linkBrandYellow = linkBrandAlt;

var radioDefault = _objectSpread2({
  radio: {
    borderHover: border.inputHover,
    border: border.input,
    backgroundChecked: background.inputChecked,
    textLabel: text.inputLabel,
    textLabelSupporting: text.inputLabelSupporting,
    borderError: border.error
  }
}, inlineErrorLight);
var radioBrand = _objectSpread2({
  radio: {
    borderHover: brandBorder.inputHover,
    border: brandBorder.input,
    backgroundChecked: brandBackground.inputChecked,
    textLabel: brandText.inputLabel,
    textLabelSupporting: brandText.supporting,
    borderError: brandBorder.error
  }
}, inlineErrorBrand); // continue to expose legacy theme names

var radioLight = radioDefault;

var textInputDefault = _objectSpread2({
  textInput: {
    textUserInput: text.userInput,
    textLabel: text.inputLabel,
    textLabelOptional: text.supporting,
    textLabelSupporting: text.supporting,
    textError: text.error,
    backgroundInput: background.input,
    border: border.input,
    borderError: border.error
  }
}, inlineErrorDefault); // continue to expose legacy theme names

var textInputLight = textInputDefault;

var defaultTheme = _objectSpread2({}, buttonDefault, {}, checkboxDefault, {}, choiceCardDefault, {}, inlineErrorDefault, {}, linkDefault, {}, radioDefault, {}, textInputDefault, {}, buttonLight, {}, checkboxLight, {}, inlineErrorLight, {}, linkLight, {}, radioLight, {}, textInputLight);
var brand$1 = _objectSpread2({}, buttonBrand, {}, checkboxBrand, {}, inlineErrorBrand, {}, linkBrand, {}, radioBrand);
var brandAlt$1 = _objectSpread2({}, buttonBrandAlt, {}, linkBrandAlt, {}, buttonBrandYellow, {}, linkBrandYellow); // continue to expose legacy theme names

var light = defaultTheme;
var brandYellow = brandAlt$1;

exports.brand = brand$1;
exports.brandAlt = brandAlt$1;
exports.brandYellow = brandYellow;
exports.buttonBrand = buttonBrand;
exports.buttonBrandAlt = buttonBrandAlt;
exports.buttonBrandYellow = buttonBrandYellow;
exports.buttonDefault = buttonDefault;
exports.buttonLight = buttonLight;
exports.checkboxBrand = checkboxBrand;
exports.checkboxDefault = checkboxDefault;
exports.checkboxLight = checkboxLight;
exports.choiceCardDefault = choiceCardDefault;
exports.defaultTheme = defaultTheme;
exports.inlineErrorBrand = inlineErrorBrand;
exports.inlineErrorDefault = inlineErrorDefault;
exports.inlineErrorLight = inlineErrorLight;
exports.light = light;
exports.linkBrand = linkBrand;
exports.linkBrandAlt = linkBrandAlt;
exports.linkBrandYellow = linkBrandYellow;
exports.linkDefault = linkDefault;
exports.linkLight = linkLight;
exports.radioBrand = radioBrand;
exports.radioDefault = radioDefault;
exports.radioLight = radioLight;
exports.textInputDefault = textInputDefault;
exports.textInputLight = textInputLight;
