export declare type ScaleUnit = "rem" | "px";
export declare type Category = "titlepiece" | "headline" | "body" | "textSans";
export declare type LineHeight = "tight" | "regular" | "loose";
export declare type FontWeight = "light" | "regular" | "medium" | "bold";
export declare type FontWeightDefinition = {
    hasItalic: boolean;
};
export declare type TitlepieceSizes = "small" | "medium" | "large";
export declare type HeadlineSizes = "xxxsmall" | "xxsmall" | "xsmall" | "small" | "medium" | "large" | "xlarge";
export declare type BodySizes = "small" | "medium";
export declare type TextSansSizes = "xsmall" | "small" | "medium" | "large" | "xlarge";
export declare type TypographyStyles = {
    fontFamily: string;
    fontSize: string | number;
    lineHeight: number;
    fontWeight?: number;
    fontStyle?: string;
};
export declare type Fs = (category: Category, level: string, { lineHeight, fontWeight, italic, unit, }: {
    lineHeight: LineHeight;
    fontWeight: FontWeight;
    italic: boolean;
    unit: ScaleUnit;
}) => TypographyStyles;
export interface FontScaleArgs {
    lineHeight?: LineHeight;
    fontWeight?: FontWeight;
    italic?: boolean;
    unit?: ScaleUnit;
}
declare const titlepieceSizes: {
    [key in TitlepieceSizes]: number;
};
declare const headlineSizes: {
    [key in HeadlineSizes]: number;
};
declare const bodySizes: {
    [key in BodySizes]: number;
};
declare const textSansSizes: {
    [key in TextSansSizes]: number;
};
declare const fontSizeMapping: {
    [cat in Category]: {
        [level in string]: number;
    };
};
declare const remFontSizes: number[];
declare const remTitlepieceSizes: {
    [key in TitlepieceSizes]: number;
};
declare const remHeadlineSizes: {
    [key in HeadlineSizes]: number;
};
declare const remBodySizes: {
    [key in BodySizes]: number;
};
declare const remTextSansSizes: {
    [key in TextSansSizes]: number;
};
declare const remFontSizeMapping: {
    [cat in Category]: {
        [level in string]: number;
    };
};
declare const fontMapping: {
    [cat in Category]: string;
};
declare const lineHeightMapping: {
    [lineHight in LineHeight]: number;
};
declare const fontWeightMapping: {
    [fontWeight in FontWeight]: number;
};
declare const availableFonts: {
    [cat in Category]: {
        [fontWeight in FontWeight]?: FontWeightDefinition;
    };
};
export { titlepieceSizes, headlineSizes, bodySizes, textSansSizes, remFontSizes, remTitlepieceSizes, remHeadlineSizes, remBodySizes, remTextSansSizes, remFontSizeMapping, fontMapping, fontSizeMapping, lineHeightMapping, fontWeightMapping, availableFonts, };
